@@ -225,7 +225,9 @@ class QA:
                 logger.error(f"Unexpected response format: {e}")
 
     def _delete(self):
-        self._qainit.delete(self._flags["hash"])
+        qa_hashes = self._flags["hashes"]
+        for qa_hash in qa_hashes:
+            self._qainit.delete(qa_hash)
 
     def _freeze(self):
         self._qainit.freeze(self._flags["hash"])
