@@ -137,7 +137,7 @@ class QainitHandler:
             "DELETE",
             f"/api/v1/qa/{qa_hash}",
         )
-        logger.info("QA deletion initiated")
+        logger.info(f"QA {qa_hash} deletion initiated")
         logger.debug(json.dumps(r.json(), indent=2))
 
     def describe(self, qa_hash):
